==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/cs/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Potvrzení hromadného odstranění majetku',
  'bulk_delete_help'	=> 'Zkontrolujte seznam odstraňovaného majetku níže. Jakmile jej potvrdíte, nebude možné tento majetek obnovit a budou zrušeny i vazby na uživatele, kteří jej měli v držení.',
  'bulk_delete_warn'	=> 'Chystáte se odstranit :asset_count položek majetku.',
	'bulk_update'		=> 'Hromadná aktualizace majetku',
	'bulk_update_help'	=> 'Tento formulář umožňuje hromadnou editaci majetku. Vyplňte pouze položky, které chcete změnit. Jakékoliv prázné položky zůstanou nezměněny. ',
	'bulk_update_warn'	=> 'Budou se editovat vlastnosti :asset_count assets.',
    'checkedout_to'		=> 'Vydané komu',
    'checkout_date'		=> 'Datum vydání',
    'checkin_date'		=> 'Datum převzetí',
    'checkout_to'		=> 'Vydat někomu',
    'cost'				=> 'Pořizovací cena',
    'create'			=> 'Vytvořit záznam majetku',
    'date'				=> 'Datum pořízení',
    'depreciation'	    => 'Amortizace',
    'depreciates_on'	=> 'Odepisuje se',
    'default_location'	=> 'Výchozí umístění',
    'eol_date'			=> 'Konec životnosti',
    'eol_rate'			=> 'Míra ukončení životnosti',
    'expected_checkin'  => 'Očekávané datum převzetí',
    'expires'			=> 'Expiruje',
    'fully_depreciated'	=> 'Plně odepsané',
    'help_checkout'		=> 'Přejete-li si přiřadit toto zařízení okamžitě, zvolte "Připraveno k předání" ze seznamu níže. ',
    'mac_address'		=> 'MAC adresa',
    'manufacturer'		=> 'Výrobce',
    'model'				=> 'Model',
    'months'			=> 'měsíce',
    'name'				=> 'Název majetku',
    'notes'				=> 'Poznámky',
    'order'				=> 'Č. objednávky',
    'qr'				=> 'QR kód',
    'requestable'		=> 'Uživatelé můžou požádat o tento majetek',
    'select_statustype'	=> 'Zvolte typ stavu',
    'serial'			=> 'Sériové číslo',
    'status'			=> 'Stav',
    'tag'				=> 'Označení majetku',
    'update'			=> 'Úprava majetku',
    'warranty'			=> 'Záruka',
		'warranty_expires'		=> 'Záruka končí',
    'years'				=> 'roky',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/cs/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Potvrzení hromadného odstranění majetku',
  'bulk_delete_help'	=> 'Zkontrolujte seznam odstraňovaného majetku níže. Jakmile jej potvrdíte, nebude možné tento majetek obnovit a budou zrušeny i vazby na uživatele, kteří jej měli v držení.',
  'bulk_delete_warn'	=> 'Chystáte se odstranit :asset_count položek majetku.',
    'bulk_update'		=> 'Hromadná aktualizace majetku',
    'bulk_update_help'	=> 'Tento formulář umožňuje hromadnou editaci majetku. Vyplňte pouze položky, které chcete změnit. Jakékoliv prázné položky zůstanou nezměněny. ',
    'bulk_update_warn'	=> 'Budou se editovat vlastnosti :asset_count assets.',
    'checkedout_to'		=> 'Vydané komu',
    'checkout_date'		=> 'Datum vydání',
    'checkin_date'		=> 'Datum převzetí',
    'checkout_to'		=> 'Vydat někomu',
    'cost'				=> 'Pořizovací cena',
    'create'			=> 'Vytvořit záznam majetku',
    'date'				=> 'Datum pořízení',
    'depreciation'	    => 'Amortizace',
    'depreciates_on'	=> 'Odepisuje se',
    'default_location'	=> 'Výchozí umístění',
    'eol_date'			=> 'Konec životnosti',
    'eol_rate'			=> 'Míra ukončení životnosti',
    'expected_checkin'  => 'Očekávané datum převzetí',
    'expires'			=> 'Expiruje',
    'fully_depreciated'	=> 'Plně odepsané',
    'help_checkout'		=> 'Přejete-li si přiřadit toto zařízení okamžitě, zvolte "Připraveno k předání" ze seznamu níže. ',
    'mac_address'		=> 'MAC adresa',
    'manufacturer'		=> 'Výrobce',
    'model'				=> 'Model',
    'months'			=> 'měsíce',
    'name'				=> 'Název majetku',
    'notes'				=> 'Poznámky',
    'order'				=> 'Č. objednávky',
    'qr'				=> 'QR kód',
    'requestable'		=> 'Uživatelé můžou požádat o tento majetek',
    'select_statustype'	=> 'Zvolte typ stavu',
    'serial'			=> 'Sériové číslo',
    'status'			=> 'Stav',
    'tag'				=> 'Označení majetku',
    'update'			=> 'Úprava majetku',
    'warranty'			=> 'Záruka',
        'warranty_expires'		=> 'Záruka končí',
    'years'				=> 'roky',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Zpracovává se...',
];
